@@ -1,7 +1,7 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable::Request::Compare;
-$Mojo::UserAgent::Mockable::Request::Compare::VERSION = '1.42';
+$Mojo::UserAgent::Mockable::Request::Compare::VERSION = '1.51';
 # VERSION
 
 # ABSTRACT: Helper class for Mojo::UserAgent::Mockable that compares two Mojo::Message::Request instances
@@ -15,6 +15,7 @@ use Safe::Isa qw{$_isa};
 has compare_result => '';
 has ignore_headers => sub { [] };
 has ignore_body => '';
+has ignore_userinfo => '';
 
 sub compare {
     my ($self, $r1, $r2) = @_;
@@ -90,6 +91,9 @@ sub _compare_url {
 
     no warnings qw/uninitialized/;
     for my $key (qw/scheme userinfo host port fragment/) {
+        my $ignore = sprintf 'ignore_%s', $key;
+        next if $self->can($ignore) && $self->$ignore;
+
         my $val1 = $u1->$key;
         my $val2 = $u2->$key;
         if ($val1 ne $val2) {
@@ -142,7 +146,7 @@ Mojo::UserAgent::Mockable::Request::Compare - Helper class for Mojo::UserAgent::
 
 =head1 VERSION
 
-version 1.42
+version 1.51
 
 =head1 ATTRIBUTES
 
@@ -150,6 +154,14 @@ version 1.42
 
 The result of the last compare operation.  It is only populated when two requests B<do not> match.
 
+=head2 ignore_userinfo 
+
+Set this to a true value to ignore a mismatch in the L<userinfo|Mojo::URL/userinfo> portion of a transaction URL.
+
+=head2 ignore_body
+
+Set this to a true value to ignore a mismatch in the bodies of the two compared transactions
+
 =head1 METHODS
 
 =head2 compare
